@@ -228,6 +228,21 @@ class Finding:  # pylint: disable=too-many-public-methods
     def __post_init__(self):
         self._logger = logging.getLogger(f'{LOGGER_BASENAME}.{self.__class__.__name__}')
 
+    def __hash__(self):
+        return hash(self.id)
+
+    def __eq__(self, other):
+        """Override the default equals behavior."""
+        if not isinstance(other, Finding):
+            raise ValueError('Not a Finding object')
+        return hash(self) == hash(other)
+
+    def __ne__(self, other):
+        """Override the default unequal behavior."""
+        if not isinstance(other, Finding):
+            raise ValueError('Not a Finding object')
+        return hash(self) != hash(other)
+
     @property
     def aws_account_id(self):
         """Account id."""
@@ -471,7 +486,7 @@ class _SecurityHub:  # pylint: disable=too-many-instance-attributes
     @retry(retry_on_exceptions=botocore.exceptions.ClientError)
     @cached(cache=TTLCache(maxsize=150000, ttl=3600))
     def _findings(self):
-        findings = []
+        findings = set()
         for region in self.regions:
             self._logger.debug(f'Trying to get findings for region {region}')
             session = boto3.Session(region_name=region)
@@ -485,11 +500,11 @@ class _SecurityHub:  # pylint: disable=too-many-instance-attributes
                     for finding_data in page['Findings']:
                         finding = Finding(finding_data)
                         self._logger.debug(f'Adding finding with id {finding.id}')
-                        findings.append(finding)
+                        findings.add(finding)
             except (security_hub.exceptions.InvalidAccessException, security_hub.exceptions.AccessDeniedException):
                 self._logger.warning(f'Check your access for Security Hub for region {region}.')
                 continue
-        return findings
+        return list(findings)
 
     @staticmethod
     def validate_frameworks(frameworks):
